'use strict';

Object.defineProperty(exports, "__esModule", {
  value: true
});

var _typeof2 = require('babel-runtime/helpers/typeof');

var _typeof3 = _interopRequireDefault(_typeof2);

var _jestMatcherUtils = require('jest-matcher-utils');

var _utils = require('./utils');

function _interopRequireDefault(obj) { return obj && obj.__esModule ? obj : { default: obj }; }

//eslint-disable-next-line import/no-extraneous-dependencies
function getDisplayName(subject) {
  if (subject && subject.constructor) {
    return subject.constructor.name;
  } else {
    return typeof subject === 'undefined' ? 'undefined' : (0, _typeof3.default)(subject);
  }
}

function checkHtmlElement(htmlElement) {
  if (!(htmlElement instanceof HTMLElement)) {
    throw new Error('The given subject is a ' + getDisplayName(htmlElement) + ', not an HTMLElement');
  }
}

var assertMessage = function assertMessage(assertionName, message, received, expected) {
  return (0, _jestMatcherUtils.matcherHint)('' + assertionName, 'received', '') + ' \n' + message + ': ' + ((0, _jestMatcherUtils.printExpected)(expected) + ' \nReceived: ' + (0, _jestMatcherUtils.printReceived)(received));
};

function printAttribute(name, value) {
  return value === undefined ? name : name + '=' + (0, _jestMatcherUtils.stringify)(value);
}

function getAttributeComment(name, value) {
  return value === undefined ? 'element.hasAttribute(' + (0, _jestMatcherUtils.stringify)(name) + ')' : 'element.getAttribute(' + (0, _jestMatcherUtils.stringify)(name) + ') === ' + (0, _jestMatcherUtils.stringify)(value);
}

var extensions = {
  toBeInTheDOM: function toBeInTheDOM(received) {
    getDisplayName(received);
    if (received) {
      return {
        message: function message() {
          return (0, _jestMatcherUtils.matcherHint)('.not.toBeInTheDOM', 'received', '') + ' Expected the element not to be present' + ('\nReceived : ' + (0, _jestMatcherUtils.printReceived)(received));
        },
        pass: true
      };
    } else {
      return {
        message: function message() {
          return (0, _jestMatcherUtils.matcherHint)('.toBeInTheDOM', 'received', '') + ' Expected the element to be present' + ('\nReceived : ' + (0, _jestMatcherUtils.printReceived)(received));
        },
        pass: false
      };
    }
  },
  toHaveTextContent: function toHaveTextContent(htmlElement, checkWith) {
    checkHtmlElement(htmlElement);
    var textContent = htmlElement.textContent;
    var pass = (0, _utils.matches)(textContent, htmlElement, checkWith);
    if (pass) {
      return {
        message: function message() {
          return assertMessage('.not.toHaveTextContent', 'Expected value not equals to', htmlElement, checkWith);
        },
        pass: true
      };
    } else {
      return {
        message: function message() {
          return assertMessage('.toHaveTextContent', 'Expected value equals to', htmlElement, checkWith);
        },
        pass: false
      };
    }
  },
  toHaveAttribute: function toHaveAttribute(htmlElement, name, expectedValue) {
    var _this = this;

    checkHtmlElement(htmlElement);
    var isExpectedValuePresent = expectedValue !== undefined;
    var hasAttribute = htmlElement.hasAttribute(name);
    var receivedValue = htmlElement.getAttribute(name);
    return {
      pass: isExpectedValuePresent ? hasAttribute && receivedValue === expectedValue : hasAttribute,
      message: function message() {
        var to = _this.isNot ? 'not to' : 'to';
        var receivedAttribute = (0, _jestMatcherUtils.RECEIVED_COLOR)(hasAttribute ? printAttribute(name, receivedValue) : 'attribute was not found');
        var expectedMsg = 'Expected the element ' + to + ' have attribute:\n  ' + (0, _jestMatcherUtils.EXPECTED_COLOR)(printAttribute(name, expectedValue));
        var matcher = (0, _jestMatcherUtils.matcherHint)((_this.isNot ? '.not' : '') + '.toHaveAttribute', 'element', (0, _jestMatcherUtils.printExpected)(name), {
          secondArgument: isExpectedValuePresent ? (0, _jestMatcherUtils.printExpected)(expectedValue) : undefined,
          comment: getAttributeComment(name, expectedValue)
        });
        return matcher + '\n\n' + expectedMsg + '\nReceived:\n  ' + receivedAttribute;
      }
    };
  }
};

exports.default = extensions;